"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loginUser = exports.getUser = exports.getAllUsers = exports.createUser = void 0;
const schema_1 = require("../db/schema");
const crypt_1 = require("../utils/crypt");
const db_1 = __importDefault(require("../db"));
const drizzle_orm_1 = require("drizzle-orm");
const http_1 = require("../constants/http");
const jwt_1 = require("../utils/jwt");
const logger_1 = require("../utils/logger");
/**
 * createUser
 */
const createUser = async ({ body }, res) => {
    try {
        const { username, firstName, lastName, email, password: plainPassword, } = body;
        const password = await (0, crypt_1.createHash)(plainPassword);
        const user = {
            firstName,
            lastName,
            email,
            username,
            password,
        };
        await db_1.default.insert(schema_1.tableUsers).values(user).returning();
        res.status(http_1.HTTP_SUCCESS.CREATED).send("User registered");
    }
    catch (error) {
        logger_1.logger.error(error);
        res
            .status(http_1.HTTP_SERVER_ERROR.INTERNAL_SERVER_ERROR)
            .send("Error registering user");
    }
};
exports.createUser = createUser;
/**
 * getAllUsers
 */
const getAllUsers = async (req, res) => {
    try {
        const result = await db_1.default.select().from(schema_1.tableUsers);
        return res.status(http_1.HTTP_SUCCESS.OK).json(result);
    }
    catch (error) {
        logger_1.logger.error(error);
        res
            .status(http_1.HTTP_SERVER_ERROR.INTERNAL_SERVER_ERROR)
            .send("Error getting users");
    }
};
exports.getAllUsers = getAllUsers;
/**
 * getUser
 */
const getUser = async (req, res) => {
    try {
        const userId = req.params.id;
        const user = await db_1.default
            .select()
            .from(schema_1.tableUsers)
            .where((0, drizzle_orm_1.eq)(schema_1.tableUsers.id, Number(userId)));
        return res.status(http_1.HTTP_SUCCESS.OK).json(user);
    }
    catch (error) {
        logger_1.logger.error(error);
        res
            .status(http_1.HTTP_SERVER_ERROR.INTERNAL_SERVER_ERROR)
            .send("Error getting users");
    }
};
exports.getUser = getUser;
/**
 * loginUser
 */
const loginUser = async ({ body }, res) => {
    try {
        const { username, password } = body;
        const results = await db_1.default
            .select()
            .from(schema_1.tableUsers)
            .where((0, drizzle_orm_1.eq)(schema_1.tableUsers.username, username));
        const user = results[0];
        if (user && (await (0, crypt_1.validateHash)(password, user.password))) {
            const accessToken = (0, jwt_1.generateJwt)(user);
            res.status(http_1.HTTP_SUCCESS.OK).json({ accessToken });
        }
        else {
            res.status(http_1.HTTP_CLIENT_ERROR.FORBIDDEN).send("Not today, buddy");
        }
    }
    catch (error) {
        res.status(http_1.HTTP_SERVER_ERROR.INTERNAL_SERVER_ERROR).send("Error logging in");
    }
};
exports.loginUser = loginUser;
