"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createUser = void 0;
const http_1 = require("../../constants/http");
const db_1 = __importDefault(require("../../db"));
const schema_1 = require("../../db/schema");
const crypt_1 = require("../../utils/crypt");
const logger_1 = require("../../utils/logger");
/**
 * createUser
 */
const createUser = async ({ body }, res) => {
    try {
        const { username, firstName, lastName, email, password: plainPassword, } = body;
        const password = await (0, crypt_1.createHash)(plainPassword);
        const user = {
            firstName,
            lastName,
            email,
            username,
            password,
        };
        await db_1.default.insert(schema_1.tableUsers).values(user).returning();
        res.status(http_1.HTTP_SUCCESS.CREATED).send("User registered");
    }
    catch (error) {
        logger_1.logger.error(error);
        res
            .status(http_1.HTTP_SERVER_ERROR.INTERNAL_SERVER_ERROR)
            .send("Error registering user");
    }
};
exports.createUser = createUser;
