"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const jwt_1 = require("../middleware/jwt");
const createUser_1 = require("../controllers/users/createUser");
const deleteUser_1 = require("../controllers/users/deleteUser");
const getAllUsers_1 = require("../controllers/users/getAllUsers");
const getUser_1 = require("../controllers/users/getUser");
const updateUser_1 = require("../controllers/users/updateUser");
const router = (0, express_1.Router)();
router
    /**
     * @swagger
     * components:
     *   schemas:
     *     User:
     *       type: object
     *       required:
     *         - id
     *         - name
     *         - email
     *       properties:
     *         id:
     *           type: string
     *           description: The auto-generated id of the user
     *         name:
     *           type: string
     *           description: The name of the user
     *         email:
     *           type: string
     *           description: The email of the user
     *       example:
     *         id: d5fE_asz
     *         name: John Doe
     *         email: john.doe@example.com
     */
    /**
     * @swagger
     * tags:
     *   name: Users
     *   description: The users managing API
     */
    /**
     * @swagger
     * /users:
     *   get:
     *     summary: Returns the list of all the users
     *     tags: [Users]
     *     responses:
     *       200:
     *         description: The list of the users
     *         content:
     *           application/json:
     *             schema:
     *               type: array
     *               items:
     *                 $ref: '#/components/schemas/User'
     */
    .get("/", jwt_1.authenticateToken, getAllUsers_1.getAllUsers)
    /**
     * @swagger
     * /users/{id}:
     *   get:
     *     summary: Get a user by ID
     *     tags: [Users]
     *     parameters:
     *       - in: path
     *         name: id
     *         schema:
     *           type: string
     *         required: true
     *         description: The user id
     *     responses:
     *       200:
     *         description: The user description by id
     *         contents:
     *           application/json:
     *             schema:
     *               $ref: '#/components/schemas/User'
     *       404:
     *         description: The user was not found
     */
    .get("/:id", jwt_1.authenticateToken, getUser_1.getUser)
    .put("/:id", jwt_1.authenticateToken, updateUser_1.updateUser)
    .delete("/:id", jwt_1.authenticateToken, deleteUser_1.deleteUser)
    .post("/register", createUser_1.createUser);
exports.default = router;
